@@ -17,8 +17,8 @@ var log = function(msg) {
 
 module.exports = {
   log: log,
-  debug: function(msg, detail) { log(chalk.green(msg) + detail); },
-  info: function(msg, detail) { log(chalk.yellow(msg) + chalk.grey(detail)); },
+  debug: function(msg, detail) { log(chalk.green(msg) + (detail || '')); },
+  info: function(msg, detail) { log(chalk.yellow(msg) + chalk.grey((detail || ''))); },
   warn: function(msg) { log(chalk.bgWhite.magenta(msg)); },
   error: function(msg) { log(chalk.bgWhite.red(msg)); }
 };
