@@ -20,6 +20,7 @@ module.exports = function(taskDef, context, helpers) {
   };
 
   var publishHotspotReport = function(publisher) {
+    publisher.enableDiagram('sloc');
     var revisionsReport = createDataSource(helpers.files.revisions(), 'revisions');
 
     var availableComplexityReports = _.filter(
@@ -31,6 +32,10 @@ module.exports = function(taskDef, context, helpers) {
       return createDataSource(file, 'totalComplexity');
     });
 
+    if (!_.isEmpty(codeComplexityReports)) {
+      publisher.enableDiagram('complexity');
+    }
+
     return new reporting.ReportComposer(helpers.files.sloc())
       .mergeAll([revisionsReport].concat(codeComplexityReports))
       .buildReport().then(function(reportData) {
@@ -39,11 +44,6 @@ module.exports = function(taskDef, context, helpers) {
       });
   };
 
-  taskDef.addTask('hotspot-report', {
-    parameters: [{ name: 'dateFrom' }, { name: 'dateTo' }],
-    reportFile: 'revisions-hotspot-data.json'
-  }, publishHotspotReport);
-
   taskDef.addAnalysisTask('hotspot-analysis', {
     description: 'Analyse the complexity and churn of source code to identify hotspots',
     parameters: [{ name: 'dateFrom' }, { name: 'dateTo' }],
