@@ -8,7 +8,8 @@
 var appConfig = require('../runtime/app_config');
 
 var vcsRepos = {
-  git: require('./git')
+  git:        require('./git'),
+  subversion: require('./svn')
 };
 
 var getCurrentRepo = function() {
@@ -25,9 +26,9 @@ module.exports = {
 
     return new Adapter(repository);
   },
-  logStreamTransformer: function(repository, developerInfo) {
-    var Transformer = getCurrentRepo().LogStreamTransfomer;
+  logStreamTransformer: function(repository, developersInfo) {
+    var Transformer = getCurrentRepo().LogStreamTransformer;
 
-    return new Transformer(repository, developerInfo);
+    return new Transformer(repository, developersInfo, this.adapter(repository));
   }
 };
