@@ -23,9 +23,10 @@ module.exports = function(manifest) {
       diagramSelectionTitle: 'View',
       dateRange: manifest.parseDateRange()
     },
-    graphModels: [
+    graphModels: manifest.selectAvailableGraphs([
       {
-        id: 'developer-coupling',
+        diagramName: 'main-developer-coupling',
+        id: 'main-developer-coupling',
         label: 'Code ownership',
         dataFile: _.find(manifest.dataFiles, { fileType: 'code-ownership' }),
         viewTemplates: ['elementInfo3TooltipTemplate'],
@@ -75,6 +76,7 @@ module.exports = function(manifest) {
         }
       },
       {
+        diagramName: 'communication-network',
         id: 'communication-network',
         label: 'Communication network',
         dataFile: _.find(manifest.dataFiles, { fileType: 'communication-network' }),
@@ -149,6 +151,6 @@ module.exports = function(manifest) {
           }
         }
       }
-    ]
+    ])
   };
 };
