@@ -57,9 +57,10 @@ module.exports = function(manifest) {
       diagramSelectionTitle: 'Effort distribution',
       dateRange: manifest.parseDateRange()
     },
-    graphModels: [
+    graphModels: manifest.selectAvailableGraphs([
       {
-        id: 'dev-effort',
+        id: 'individual-effort',
+        diagramName: 'individual-effort',
         label: 'By developer',
         dataFile: _.find(manifest.dataFiles, { fileType: 'individual-effort' }),
         controlTemplates: {
@@ -71,6 +72,7 @@ module.exports = function(manifest) {
       },
       {
         id: 'team-effort',
+        diagramName: 'team-effort',
         label: 'By team',
         dataFile: _.find(manifest.dataFiles, { fileType: 'team-effort' }),
         controlTemplates: {
@@ -80,6 +82,6 @@ module.exports = function(manifest) {
         },
         diagram: diagramConfig()
       }
-    ]
+    ])
   };
 };
